package zero1hd.polyjet.ui.pages;

import java.io.File;
import java.io.FilenameFilter;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Preferences;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.actions.Actions;
import com.badlogic.gdx.scenes.scene2d.ui.Image;
import com.badlogic.gdx.scenes.scene2d.ui.ScrollPane;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;

import zero1hd.polyjet.Polyjet;
import zero1hd.polyjet.screens.MainMenu;
import zero1hd.polyjet.ui.builders.MusicSelectable;

public class MusicSelectionPage extends Page {
	Image loading;
	private volatile Table musicChoices;
	Preferences musicFileAnnotation;
	private Polyjet core;
	
	public MusicSelectionPage(final Polyjet core, final MainMenu mainMenu) {
		super("Select music", core.defaultSkin);
		this.core = core;
		
		musicFileAnnotation = Gdx.app.getPreferences("music_file_annotation");
		
		
		TextButton back = new TextButton("Back", core.defaultSkin);
		back.setPosition(getWidth()-back.getWidth()-15f, getHeight()-back.getHeight()-15f);
		back.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				core.setScreen(mainMenu);
			}
		});
		addActor(back);
		
		loading = new Image(core.defaultSkin, "loading");
		loading.setPosition((getWidth()-loading.getWidth())/2, (getHeight()-loading.getHeight())/2);
		loading.setOrigin(loading.getWidth()/2, loading.getHeight()/2);
		loading.addAction(Actions.forever(Actions.rotateBy(-360f, 2f)));
		addActor(loading);
		
		musicChoices = new Table();
		musicChoices.defaults().pad(10f);
		ScrollPane musicChoiceScroller = new ScrollPane(musicChoices);
		musicChoiceScroller.setSize(getWidth(), getHeight()*0.85f);
		addActor(musicChoiceScroller);
	}
	
	@Override
	public void act(float delta) {
		if (musicChoices.hasChildren()) {
			loading.remove();
		}
		super.act(delta);
	}
	
	public void beginMusicSearch() {
		new Thread(new Runnable() {
			
			@Override
			public void run() {
				
				FileHandle[] musicFiles = new FileHandle(core.prefs.getString("music dir")).list(new FilenameFilter() {
					@Override
					public boolean accept(File dir, String name) {
						if (name.endsWith("mp3") || name.endsWith("wav")) {
							return true;
						}
						return false;
					}
				});
				for (int music = 0; music < musicFiles.length; music++) {
					final MusicSelectable selectable = new MusicSelectable(musicFiles[music], musicFileAnnotation, core.defaultSkin, core.assetManager.get("defaultCover.png", Texture.class));
					Gdx.app.postRunnable(new Runnable() {
						@Override
						public void run() {
							musicChoices.add(selectable).size(256f, 0.8f*getHeight());
							selectable.addInfoToPanel();
						}
					});
				}
			}
		}).start();
	}
}
